@@ -3,7 +3,7 @@ package Test::BDD::Cucumber::Harness::Html;
 use Moose;
 
 # ABSTRACT: html output for Test::BDD::Cucumber
-our $VERSION = '1.004'; # VERSION
+our $VERSION = '1.005'; # VERSION
 
 
 use Time::HiRes qw ( time );
@@ -28,10 +28,10 @@ has step_start_at    => ( is => 'rw', isa => 'Num' );
 has 'template' => ( is => 'ro', isa => 'Template', lazy => 1,
 	default => sub {
 		my $self = shift;
-                return Template->new(
-                        ABSOLUTE => 1,
-                        EVAL_PERL => 1,
-                );
+      return Template->new(
+        ABSOLUTE => 1,
+        EVAL_PERL => 1,
+      );
 	},
 );
 
@@ -72,157 +72,183 @@ has 'statistic' => ( is => 'ro', isa => 'HashRef', lazy => 1,
 );
 
 sub feature {
-    my ( $self, $feature ) = @_;
-    $self->current_feature( $self->format_feature($feature) );
-    push @{ $self->all_features }, $self->current_feature;
+  my ( $self, $feature ) = @_;
+  $self->current_feature( $self->format_feature($feature) );
+  push @{ $self->all_features }, $self->current_feature;
 }
 
 sub scenario {
-    my ( $self, $scenario, $dataset ) = @_;
-    $self->current_scenario( $self->format_scenario($scenario) );
-    push @{ $self->current_feature->{elements} }, $self->current_scenario;
+  my ( $self, $scenario, $dataset ) = @_;
+  $self->current_scenario( $self->format_scenario($scenario) );
+  push @{ $self->current_feature->{elements} }, $self->current_scenario;
 }
 
 sub step {
-    my ( $self, $context ) = @_;
-    $self->step_start_at( time() );
+  my ( $self, $context ) = @_;
+  $self->step_start_at( time() );
 }
 
 sub step_done {
-    my ( $self, $context, $result ) = @_;
-    my $duration = time() - $self->step_start_at;
-    my $step_data = $self->format_step( $context, $result, $duration );
-    my $status = $step_data->{'result'}->{'status'};
+  my ( $self, $context, $result ) = @_;
+  my $duration = time() - $self->step_start_at;
+  my $step_data = $self->format_step( $context, $result, $duration );
+  my $status = $step_data->{'result'}->{'status'};
 
-    $self->current_feature->{'statistic'}->{ $status }++;
-    $self->current_scenario->{'statistic'}->{ $status }++;
-    $self->statistic->{ $status }++;
+  $self->current_feature->{'statistic'}->{ $status }++;
+  $self->current_scenario->{'statistic'}->{ $status }++;
+  $self->statistic->{ $status }++;
 
-    push @{ $self->current_scenario->{steps} }, $step_data;
+  push @{ $self->current_scenario->{steps} }, $step_data;
 }
 
 sub shutdown {
-    my ($self) = @_;
-    my $html;
-    my $template = $self->template_content;
-    my $vars = {
-	    'all_features' => $self->all_features,
-	    'statistic' => $self->statistic,
-	    'title' => $self->title,
-	    'time' => Time::Piece->new(),
-	    'hostname' => hostname(),
-	    'command' => join(' ', $0, @ARGV),
-    };
-    $self->template->process( \$template, $vars, $self->fh )
-        or die $self->template->error;
+  my ($self) = @_;
+  my $html;
+  my $template = $self->template_content;
+  my $vars = {
+    'all_features' => $self->all_features,
+    'statistic' => $self->statistic,
+    'title' => $self->title,
+    'time' => Time::Piece->new(),
+    'hostname' => hostname(),
+    'command' => join(' ', $0, @ARGV),
+  };
+  $self->template->process( \$template, $vars, $self->fh )
+      or die $self->template->error;
 }
 
 sub get_keyword {
-    my ( $self, $line_ref ) = @_;
-    my ($keyword) = $line_ref->content =~ /^(\w+)/;
-    return $keyword;
+  my ( $self, $line_ref ) = @_;
+  my ($keyword) = $line_ref->content =~ /^(\w+)/;
+  return $keyword;
 }
 
 sub format_tags {
-    my ( $self, $tags_ref ) = @_;
-    return [ map { { name => '@' . $_ } } @$tags_ref ];
+  my ( $self, $tags_ref ) = @_;
+  return [ map { { name => '@' . $_ } } @$tags_ref ];
 }
 
 sub format_description {
-    my ( $self, $feature ) = @_;
-    return join "\n", map { $_->content } @{ $feature->satisfaction };
+  my ( $self, $feature ) = @_;
+  return join "\n", map { $_->content } @{ $feature->satisfaction };
 }
 
 sub format_feature {
-    my ( $self, $feature ) = @_;
-    return {
-        uri         => $feature->name_line->filename,
-        keyword     => $self->get_keyword( $feature->name_line ),
-        id          => "feature-" . int($feature),
-        name        => $feature->name,
-        line        => $feature->name_line->number,
-        description => $self->format_description($feature),
-        tags        => $self->format_tags( $feature->tags ),
-        elements    => [],
-	statistic => { map { $_ => 0 } values %{$self->_output_status} },
-    };
+  my ( $self, $feature ) = @_;
+  return {
+    uri         => $feature->name_line->filename,
+    keyword     => $self->get_keyword( $feature->name_line ),
+    id          => "feature-" . int($feature),
+    name        => $feature->name,
+    line        => $feature->name_line->number,
+    description => $self->format_description($feature),
+    tags        => $self->format_tags( $feature->tags ),
+    elements    => [],
+    statistic   => { map { $_ => 0 } values %{$self->_output_status} },
+  };
 }
 
 sub format_scenario {
-    my ( $self, $scenario, $dataset ) = @_;
-    return {
-        keyword => $self->get_keyword( $scenario->line ),
-        id      => "scenario-" . int($scenario),
-        name    => $scenario->name,
-        line    => $scenario->line->number,
-        tags    => $self->format_tags( $scenario->tags ),
-        type    => $scenario->background ? 'background' : 'scenario',
-        steps   => [],
-	statistic => { map { $_ => 0 } values %{$self->_output_status} },
-    };
+  my ( $self, $scenario, $dataset ) = @_;
+  return {
+    keyword => $self->get_keyword( $scenario->line ),
+    id      => "scenario-" . int($scenario),
+    name    => $scenario->name,
+    line    => $scenario->line->number,
+    tags    => $self->format_tags( $scenario->tags ),
+    type    => $scenario->background ? 'background' : 'scenario',
+    steps   => [],
+    statistic => { map { $_ => 0 } values %{$self->_output_status} },
+  };
 }
 
 sub format_step {
-    my ( $self, $step_context, $result, $duration ) = @_;
-    my $step = $step_context->step;
-    my $rand = int( rand() * 10000000);
-    return {
-        keyword => $step ? $step->verb_original : $step_context->verb,
-        id => "step-".$rand, 
-        name => $step_context->text,
-        data_text => ref($step_context->data) ? undef : $step_context->data,
-        data_table => ref($step_context->data) eq 'ARRAY' ? $step_context->data : undef,
-        background => $step_context->background,
-        line => $step ? $step->line->number : 0,
-        result => $self->format_result( $result, $duration )
-    };
+  my ( $self, $step_context, $result, $duration ) = @_;
+  my $step = $step_context->step;
+  my $rand = int( rand() * 10000000);
+  return {
+    keyword => $step ? $step->verb_original : $step_context->verb,
+    keyword_en => $step_context->verb,
+    id => "step-".$rand, 
+    name => $step_context->text,
+    data_text => ref($step_context->data) ? undef : $step_context->data,
+    data_table => ref($step_context->data) eq 'ARRAY' ? $step_context->data : undef,
+    background => $step_context->background,
+    line => $step ? $step->line->number : 0,
+    result => $self->format_result( $result, $duration )
+  };
 }
 
 has '_output_status' => ( is => 'ro', isa => 'HashRef', lazy => 1,
-	    default => sub { {
-	    passing   => 'passed',
-	    failing   => 'failed',
-	    pending   => 'pending',
-	    undefined => 'skipped',
-    } },
+  default => sub { {
+    passing   => 'passed',
+    failing   => 'failed',
+    pending   => 'pending',
+    undefined => 'skipped',
+  } },
 );
 
 sub format_result {
-    my ( $self, $result, $duration ) = @_;
-    my $ret;
+  my ( $self, $result, $duration ) = @_;
+  my $ret;
 
-    if( $result ) {
-	    $ret = {
-		status        => $self->_output_status->{ $result->result },
-		error_message => $result->output,
-		defined $duration
-		? ( duration => int( $duration * 1_000_000_000 ) )
-		: (),    # nanoseconds
-	    };
-    } else {
-    	$ret = { status => "undefined" };
-    }
+  if( $result ) {
+    $ret = {
+      status        => $self->_output_status->{ $result->result },
+      error_message => $result->output,
+      defined $duration
+        ? ( duration => int( $duration * 1_000_000_000 ) )
+        : (),    # nanoseconds
+    };
+  } else {
+  	$ret = { status => "undefined" };
+  }
 
-    return $ret;
+  return $ret;
 }
 
 1;
 
-
-
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Test::BDD::Cucumber::Harness::Html - html output for Test::BDD::Cucumber
 
 =head1 VERSION
 
-version 1.004
+version 1.005
 
 =head1 DESCRIPTION
 
-A L<Test::BDD::Cucumber::Harness> subclass that generates html output.
+A L<Test::BDD::Cucumber::Harness> subclass that generates html reports.
+
+=head1 EXAMPLE USAGE
+
+  $ pherkin -o Html features/ > test-report.html
+
+=head1 EXAMPLE OUTPUT
+
+The default template uses bootstrap CSS for formatting.
+
+Example test reports from the L<Test::BDD::Cucumber> examples
+are included in the distribution tar ball or can be viewed online at:
+
+=over
+
+=item Calculator example
+
+L<https://markusbenning.de/cucumber-html-examples/calculator-report.html>
+
+=item Digest example
+
+L<https://markusbenning.de/cucumber-html-examples/digest-report.html>
+
+=back
+
+=head1 HOW IT WORKS
 
 All report data is gathered and stored in $self->all_features.
 
@@ -271,7 +297,6 @@ the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-
 __DATA__
 [% PERL -%]
 $stash->set( 'map_bootstrap_class', sub {
@@ -281,6 +306,9 @@ $stash->set( 'map_bootstrap_class', sub {
 		'skipped' => 'info',
 		'failed' => 'danger',
 		'pending' => 'warning',
+		'given' => 'success',
+		'when' => 'info',
+		'then' => 'warning',
 	};
 	return( $map->{ $status } );
 } );
@@ -317,22 +345,22 @@ $stash->set( 'map_bootstrap_class', sub {
 [% BLOCK toc -%]
 <ul>
 [% FOREACH f = all_features -%]
-  <li><a href="#[% f.id %]">[% f.name %]</a>[% INCLUDE statistic_tags s=f.statistic size='xs' %]</li>
+  <li><a href="#[% f.id %]">[% f.name FILTER html %]</a>[% INCLUDE statistic_tags s=f.statistic size='xs' %]</li>
   <ul>
   [% FOREACH s = f.scenarios -%]
-    <li><a href="#[% s.id %]">[% s.name %]</a>[% INCLUDE statistic_tags s=s.statistic size='xs' %]</li>
+    <li><a href="#[% s.id %]">[% s.name FILTER html %]</a>[% INCLUDE statistic_tags s=s.statistic size='xs' %]</li>
   [% END -%]
   </ul>
 [% END -%]
 </ul>
 [% END -%]
 [% BLOCK scenario -%]
-<h3 id="[% s.id %]">[% s.name %]</h3>
+<h3 id="[% s.id %]">[% s.name FILTER html %]</h3>
 <div class="panel-group" id="[% s.id %]-accordion">
 [% FOREACH step = s.steps -%]
 <div class="panel panel-[% map_bootstrap_class(step.result.status) %]">
 	<div class="panel-heading"><a data-toggle="collapse" data-target="#[% step.id %]-body">
-<b>[% step.keyword %]</b> [% step.name %]
+<b class="text-[% map_bootstrap_class(step.keyword_en) %]">[% step.keyword %]</b> [% step.name FILTER html %]
 
 <div class="step-line">([% step.background ? 'background, ' : '' %]line: [% step.line %])</div>
 <div class="step-result">[% step.result.status %]</div>
@@ -352,8 +380,8 @@ $stash->set( 'map_bootstrap_class', sub {
 </div>
 [% END -%]
 [% BLOCK feature -%]
-<h2 id="[% f.id %]">[% f.name %] <small>([% f.uri %]) [% INCLUDE statistic_tags s=f.statistic %]</small></h2>
-<p>[% f.description %]</p>
+<h2 id="[% f.id %]">[% f.name FILTER html %] <small>([% f.uri %]) [% INCLUDE statistic_tags s=f.statistic %]</small></h2>
+<pre><code>[% f.description FILTER html %]</code></pre>
 [% FOREACH scenario = f.scenarios -%]
     [% INCLUDE scenario s=scenario -%]
 [% END -%]
